#/bin/sh

CHAP=5
APPNAME=gcc
APPVER=.2
VER=8.2.0
TARGET=$APPNAME-$VER
TARGETBALL=$TARGET.tar.xz
TARGETDIR=$TARGET

VER_mpfr=4.0.1
VER_gmp=6.1.2
VER_gmp2=${VER_gmp}
VER_mpc=1.1.0

. ./_lfsset.sh

cd $SRC

echo $TARGET

echo \ \ Removing old directory...
rm -fr $TARGETDIR

. $WRK/_extract.sh

cd $TARGETDIR

cat gcc/limitx.h gcc/glimits.h gcc/limity.h > \
  `dirname $($LFS_TGT-gcc -print-libgcc-file-name)`/include-fixed/limits.h

for file in gcc/config/{linux,i386/linux{,64}}.h
do
  cp -uv $file{,.orig}
  sed -e 's@/lib\(64\)\?\(32\)\?/ld@/tools&@g' \
      -e 's@/usr@/tools@g' $file.orig > $file
  echo '
#undef STANDARD_STARTFILE_PREFIX_1
#undef STANDARD_STARTFILE_PREFIX_2
#define STANDARD_STARTFILE_PREFIX_1 "/tools/lib/"
#define STANDARD_STARTFILE_PREFIX_2 ""' >> $file
  touch $file.orig
done

case $(uname -m) in
  x86_64)
    sed -e '/m64=/s/lib64/lib/' \
        -i.orig gcc/config/i386/t-linux64
  ;;
esac

echo \ \ Extracting...
tar -xf $DLD/mpfr-$VER_mpfr.tar.xz || exit 1
mv mpfr-$VER_mpfr mpfr
tar -xf $DLD/gmp-${VER_gmp2}.tar.xz || exit 1
mv gmp-$VER_gmp gmp
tar -xf $DLD/mpc-$VER_mpc.tar.gz || exit 1
mv mpc-$VER_mpc mpc 

TimeStart

mkdir build
cd    build

echo \ \ Configuring...
CC=$LFS_TGT-gcc                                    \
CXX=$LFS_TGT-g++                                   \
AR=$LFS_TGT-ar                                     \
RANLIB=$LFS_TGT-ranlib                             \
../configure                                       \
    --prefix=/tools                                \
    --with-local-prefix=/tools                     \
    --with-native-system-header-dir=/tools/include \
    --enable-languages=c,c++                       \
    --disable-libstdcxx-pch                        \
    --disable-multilib                             \
    --disable-bootstrap                            \
    --disable-libgomp                              \
	1> $LOG/$CHAP.$TARGET.1_conf.log 2>&1 || exit 1

echo \ \ Making...
make \
	1> $LOG/$CHAP.$TARGET.2_make.log 2>&1 || exit 1

echo \ \ Installing...
make install \
	1> $LOG/$CHAP.$TARGET.3_install.log 2>&1 || exit 1

ln -sv gcc /tools/bin/cc \
	1>> $LOG/$CHAP.$TARGET.3_install.log 2>&1 || exit 1

echo 'int main(){}' > dummy.c
cc dummy.c
readelf -l a.out | grep ': /tools'
rm dummy.c a.out

TimeEnd chap5

echo \ \ Removing directory...
cd ../..
rm -fr $TARGETDIR

echo \ \ Done.
